@@ -7,11 +7,11 @@ CGI::Application::Plugin::AnyTemplate - Use any templating system from within CG
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 =head1 SYNOPSIS
 
@@ -51,7 +51,7 @@ C<CGI::Application::Plugin::AnyTemplate> allows you to use any
 supported Perl templating system using a single consistent interface.
 
 Currently supported templating systems include L<HTML::Template>,
-L<HTML::Template::Expr>, L<Template::Toolkit> and L<Petal>.
+L<HTML::Template::Expr>, L<Template::Toolkit|Template> and L<Petal>.
 
 You can access any of these templating systems using the same interface.
 In this way, you can use the same code and switch templating systems on
@@ -70,7 +70,7 @@ at the bottom of every page.
 These components are actually full L<CGI::Application> run modes, and
 can do anything normal run mode can do, including processing form
 parameters and filling in their own templates.  See
-below under L<COMPONENT DISPATCH> for details.
+below under L<"COMPONENT DISPATCH"> for details.
 
 =head2 Multiple Named Template Configurations
 
@@ -148,7 +148,7 @@ or (with slightly less typing):
     $template->param('foo' => 'bar');
     $template->output;
 
-See also below under L<CHANGING THE NAME OF THE 'template' METHOD>.
+See also below under L<"CHANGING THE NAME OF THE 'template' METHOD">.
 
 =cut
 
@@ -279,7 +279,7 @@ then the actual filename will depend on the current template driver:
     Petal                  myfile.xhtml
 
 The per-type extension is controlled by the driver config for each
-C<AnyTemplate> driver (see below under L<Driver Configuration> for how
+C<AnyTemplate> driver (see below under L<"Driver and Native Configuration"> for how
 to set this).
 
 The C<auto_add_template_extension> feature is on by default.  To disable
@@ -347,10 +347,17 @@ C<Template::Toolkit> configuration parameter.
 For details on driver configuration, see the docs for the individual
 drivers:
 
-    CGI::Application::Plugin::AnyTemplate::Driver::HTMLTemplate
-    CGI::Application::Plugin::AnyTemplate::Driver::HTMLTemplateExpr
-    CGI::Application::Plugin::AnyTemplate::Driver::TemplateToolkit
-    CGI::Application::Plugin::AnyTemplate::Driver::Petal
+=over 4
+
+=item L<CGI::Application::Plugin::AnyTemplate::Driver::HTMLTemplate>
+
+=item L<CGI::Application::Plugin::AnyTemplate::Driver::HTMLTemplateExpr>
+
+=item L<CGI::Application::Plugin::AnyTemplate::Driver::TemplateToolkit>
+
+=item L<CGI::Application::Plugin::AnyTemplate::Driver::Petal>
+
+=back
 
 =head3 Copying Query data into Templates
 
@@ -460,7 +467,7 @@ you can specify filename and configuration paramters directly:
     );
 
 The configuration is merged with the configuration that was passed to
-L<config>.
+L<"config">.
 
 You can include any of the configuration parameters that you can pass to
 config, plus the following extra parameters:
@@ -805,7 +812,7 @@ sub fill {
 
 =head2 process
 
-C<process> is an alias for L<fill>.
+C<"process"> is an alias for L<"fill">.
 
 =cut
 
@@ -903,7 +910,7 @@ to the output generated by the template.  You can modify this output:
 
 
 When you call the C<output> method, any components embedded in the
-template are run.  See L<COMPONENT DISPATCH>, below.
+template are run.  See L<"COMPONENT DISPATCH">, below.
 
 
 =head1 COMPONENT DISPATCH
@@ -938,7 +945,7 @@ L<HTML::Template::Expr> syntax:
 
     <TMPL_VAR EXPR="CGIAPP_dispatch('some_run_mode')">
 
-L<Template::Toolkit> syntax:
+L<Template::Toolkit|Template> syntax:
 
     [% CGIAPP.dispatch("some_run_mode") %]
 
@@ -990,14 +997,14 @@ L<HTML::Template> syntax:
 
 I<Note that HTML::Template doesn't support this type of callback natively>
 I<and that this behaviour is emulated by the HTMLTemplate driver>
-I<see the docs to> L<CGI::Application::AnyTemplate::Driver::HTMLTemplate>
+I<see the docs to> L<CGI::Application::Plugin::AnyTemplate::Driver::HTMLTemplate>
 I<for limitations to the emulation>.
 
 L<HTML::Template::Expr> syntax:
 
     <TMPL_VAR EXPR="CGIAPP_dispatch('some_run_mode', param1, 'literal string2')">
 
-L<Template::Toolkit> syntax:
+L<Template::Toolkit|Template> syntax:
 
     [% CGIAPP.dispatch("some_run_mode", param1, 'literal string2' ) %]
 
